Crate iso3166_3

Crate iso3166_3 

Structs

FormerCountryCode
Struct defining a Former Country Code as defined by ISO 3166-3.
FormerCountryCodeCodes
A representation of a Former Country Code’s ISO 3166-1 information.

Functions

all
Returns Vec of all FormerCountryCodes defined by ISO 3166-3.
code
Returns the FormerCountryCode if one is found matching the given code.
validity
Returns a Vec of ISO 3166-3 FormerCountryCodes that were valid from a range of the given years.